tool_fn_mut

Macro tool_fn_mut 

macro_rules! tool_fn_mut {
    () => { ... };
}
This is a hack that must be given as the final argument of the MCP server builder’s tool_fn_mut method when defining tools.

The agent-client-protocol-rmcp crate provides the builder this macro is typically used with. Look away, lest ye be blinded by its vileness!

Fine, if you MUST know, it’s a horrific workaround for not having return-type notation and for this !@$#!%! bug. Trust me, the need for it hurts me more than it hurts you. –nikomatsakis